darkhistory.electrons.positronium.weighted\_photon\_spec
========================================================

.. currentmodule:: darkhistory.electrons.positronium

.. autofunction:: weighted_photon_spec